HitsAtK
=======

.. currentmodule:: pykeen.metrics.ranking

.. autoclass:: HitsAtK
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~HitsAtK.binarize
      ~HitsAtK.closed_expectation
      ~HitsAtK.closed_variance
      ~HitsAtK.increasing
      ~HitsAtK.key
      ~HitsAtK.name
      ~HitsAtK.needs_candidates
      ~HitsAtK.supported_rank_types
      ~HitsAtK.supports_weights
      ~HitsAtK.synonyms
      ~HitsAtK.value_range

   .. rubric:: Methods Summary

   .. autosummary::

      ~HitsAtK.__call__
      ~HitsAtK.expected_value
      ~HitsAtK.extra_repr
      ~HitsAtK.get_description
      ~HitsAtK.get_link
      ~HitsAtK.get_range
      ~HitsAtK.get_sampled_values
      ~HitsAtK.iter_extra_repr
      ~HitsAtK.numeric_expected_value
      ~HitsAtK.numeric_expected_value_with_ci
      ~HitsAtK.numeric_variance
      ~HitsAtK.numeric_variance_with_ci
      ~HitsAtK.std
      ~HitsAtK.variance

   .. rubric:: Attributes Documentation

   .. autoattribute:: binarize
   .. autoattribute:: closed_expectation
   .. autoattribute:: closed_variance
   .. autoattribute:: increasing
   .. autoattribute:: key
   .. autoattribute:: name
   .. autoattribute:: needs_candidates
   .. autoattribute:: supported_rank_types
   .. autoattribute:: supports_weights
   .. autoattribute:: synonyms
   .. autoattribute:: value_range

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: expected_value
   .. automethod:: extra_repr
   .. automethod:: get_description
   .. automethod:: get_link
   .. automethod:: get_range
   .. automethod:: get_sampled_values
   .. automethod:: iter_extra_repr
   .. automethod:: numeric_expected_value
   .. automethod:: numeric_expected_value_with_ci
   .. automethod:: numeric_variance
   .. automethod:: numeric_variance_with_ci
   .. automethod:: std
   .. automethod:: variance
